@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -47,9 +47,9 @@ def get_symlink_commands():
     symlinks = "/var/lib/calculate/calculate-core/conf/symlinks"
     for line in readLinesFile(symlinks):
         yield line.strip()
-    yield "/usr/sbin/cl-core"
-    yield "/usr/sbin/cl-update"
-    yield "/usr/sbin/cl-core-patch"
+    yield "/usr/bin/cl-core"
+    yield "/usr/bin/cl-update"
+    yield "/usr/bin/cl-core-patch"
 
 
 def search_worked_process(method_name, clVars,
